cd "/Users/marcmere/Box Sync/QJPS Paper/Replication Data/"
cap log close
log using "CreateFigures.log", replace

/* 
Generates:
// Figure 2
// Figure A.4
// Figure 3 */

clear all
set more off
graph set ps logo off
graph set ps pagesize a4

local beginyear = "2002"
local beginmonth = "01"
local endyear = "2008"
local endmonth = "09"
local lowerbound = monthly("`beginyear'-`beginmonth'", "YM")
local upperbound = monthly("`endyear'-`endmonth'", "YM")
local cutoff_month1 = monthly("2005-06", "YM")
local cutoff_date1 = date("2005-06-30", "YMD")

use "VFFelonMatch2010_0.dta", clear

gen monthstring = reverse(substr(reverse(dischargedate), 1, 4)) + "-" + subinstr(substr(dischargedate, 1, 2), "/","",1)
gen month = monthly(monthstring, "YM")
keep if month >= `lowerbound' & month <= `upperbound'

gen month_discharge = real(subinstr(substr(dischargedate, 1, 2), "/","",1))
gen temp = substr(dischargedate, strpos(dischargedate, "/") + 1, .)
gen day_discharge = real(subinstr(substr(temp, 1, 2), "/","",1))
drop temp
gen year_discharge = real(reverse(substr(reverse(dischargedate), 1, 4)))

gen obs = 1
tab offenseclass
gen felony = (regexm(offenseclass, "Felony"))

collapse (sum) obs registered y2008, by(month monthstring)

tsset month, monthly
format month %tmMonYY

local temp = max(`endmonth' - 3, 1)

gen percreg = registered / obs
gen perc2008 = y2008 / obs

twoway (scatter percreg month if month <= `cutoff_month1', mfcolor(white) mlcolor(black) msymbol(circle)) /*
*/ (scatter percreg month if month > `cutoff_month1', mfcolor(black) mlcolor(black) msymbol(circle)), /*
*/ ytitle("Percent Registered") ttitle("") /*
*/ legend(off) /*
*/ ttick(`beginyear'm`beginmonth'(6)`endyear'm`temp') /*
*/ tlabel(`beginyear'm`beginmonth'(12)`endyear'm`temp') /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) 

graph export "Iowa2010MonthlyReg_nolabel.eps", replace

twoway (scatter perc2008 month if month <= `cutoff_month1', mfcolor(white) mlcolor(black) msymbol(circle)) /*
*/ (scatter perc2008 month if month > `cutoff_month1', mfcolor(black) mlcolor(black) msymbol(circle)), /*
*/ ytitle("Percent Voting in 2008 Presidential Election") ttitle("Month and Year of Discharge") /*
*/ legend(lab(1 "Didn't Receive Restoration Certificate") /*
*/ lab(2 "Received Restoration Certificate") region(lstyle(none))) /*
*/ ttick(`beginyear'm`beginmonth'(6)`endyear'm`temp') /*
*/ tlabel(`beginyear'm`beginmonth'(12)`endyear'm`temp') /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) 

graph export "Iowa2010Monthly2008.eps", replace

local beginyear = "2002"
local beginmonth = "01"
local endyear = "2012"
local endmonth = "02"
local lowerbound = monthly("`beginyear'-`beginmonth'", "YM")
local upperbound = monthly("`endyear'-`endmonth'", "YM")
local cutoff_month1 = monthly("2005-06", "YM")
local cutoff_month2 = monthly("2010-12", "YM")

use "VFFelonMatch01082013_0.dta", clear

gen monthstring = reverse(substr(reverse(dischargedate), 1, 4)) + "-" + subinstr(substr(dischargedate, 1, 2), "/","",1)
gen month = monthly(monthstring, "YM")
keep if month >= `lowerbound' & month <= `upperbound'

gen month_discharge = real(subinstr(substr(dischargedate, 1, 2), "/","",1))
gen temp = substr(dischargedate, strpos(dischargedate, "/") + 1, .)
gen day_discharge = real(subinstr(substr(temp, 1, 2), "/","",1))
drop temp
gen year_discharge = real(reverse(substr(reverse(dischargedate), 1, 4)))

gen obs = 1
tab offenseclass
gen felony = (regexm(offenseclass, "Felony"))

collapse (sum) obs felony, by(month monthstring)

tsset month, monthly
format month %tmMonYY

local temp = max(`endmonth' - 3, 1)

twoway (scatter obs month if month <= `cutoff_month1', mfcolor(white) mlcolor(black) msymbol(circle)) /*
*/ (scatter obs month if month > `cutoff_month1' & month <= `cutoff_month2', mfcolor(gs8) mlcolor(gs8) msymbol(circle)) /*
*/ (scatter obs month if month > `cutoff_month2', mfcolor(black) mlcolor(black) msymbol(circle)), /*
*/ ytitle("# of Discharges") ttitle("") /*
*/ legend(off) /*
*/ tlabel(`beginyear'm`beginmonth'(12)`endyear'm`temp') /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) 

graph export "IowaMonthlyObs_nolabel.eps", replace

twoway (scatter felony month if month <= `cutoff_month1', mfcolor(white) mlcolor(black) msymbol(circle)) /*
*/ (scatter felony month if month > `cutoff_month1' & month <= `cutoff_month2', mfcolor(black) mlcolor(black) msymbol(circle)) /*
*/ (scatter felony month if month > `cutoff_month2', mfcolor(gs8) mlcolor(gs8) msymbol(circle)), /*
*/ ytitle("# of Felony Discharges" "") ttitle("Month and Year of Discharge") /*
*/ legend(lab(1 "Voting Rights Automatically Restored, Didn't Receive Restoration Certificate") /*
*/ lab(2 "Voting Rights Automatically Restored, Received Restoration Certificate") /*
*/ lab(3 "Voting Rights Not Automatically Restored") position(6) rows(3) region(lstyle(none))) /*
*/ tlabel(`beginyear'm`beginmonth'(12)`endyear'm`temp') /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) 

graph export "IowaMonthlyFelonyObs.eps", replace

local beginyear = "2002"
local beginquarter= "01"
local endyear = "2012"
local endquarter = "01"
local lowerbound = quarterly("`beginyear'-`beginquarter'", "YQ")
local upperbound = quarterly("`endyear'-`endquarter'", "YQ")
local cutoff_quarter1 = quarterly("2005-02", "YQ")
local cutoff_quarter2 = quarterly("2008-03", "YQ")
local cutoff_quarter3 = quarterly("2010-03", "YQ")
local cutoff_quarter4 = quarterly("2010-04", "YQ")
use "VFFelonMatch01082013_0.dta", clear

gen temp = "01" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "1"
replace temp = "01" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "2" 
replace temp = "01" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "3" 
replace temp = "02" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "4" 
replace temp = "02" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "5" 
replace temp = "02" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "6" 
replace temp = "03" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "7" 
replace temp = "03" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "8" 
replace temp = "03" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "9" 
replace temp = "04" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "10" 
replace temp = "04" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "11" 
replace temp = "04" if subinstr(substr(dischargedate, 1, 2), "/","",1) == "12"

gen quarterstring = reverse(substr(reverse(dischargedate), 1, 4)) + "-" + temp
drop temp

gen quarter = quarterly(quarterstring, "YQ")
keep if quarter >= `lowerbound' & quarter <= `upperbound'

gen obs = 1
collapse (sum) obs registered y2012, by(quarter quarterstring)

tsset quarter, quarterly

local temp = max(`endquarter' -  1, 1)

gen percreg = registered / obs
gen perc2012 = y2012 / obs

twoway (scatter percreg quarter if quarter <= `cutoff_quarter1', mfcolor(black) mlcolor(black) msymbol(circle)) /*
*/ (scatter percreg quarter if quarter > `cutoff_quarter1' & quarter <= `cutoff_quarter2', mfcolor(gs12) mlcolor(gs12) msymbol(circle)) /*
*/ (scatter percreg quarter if quarter > `cutoff_quarter2' & quarter <= `cutoff_quarter3', mfcolor(white) mlcolor(black) msymbol(circle)) /*
*/ (scatter percreg quarter if quarter > `cutoff_quarter3' & quarter <= `cutoff_quarter4', mfcolor(gs12) mlcolor(black) msymbol(circle)) /*
*/ (scatter percreg quarter if quarter > `cutoff_quarter4', mfcolor(gs8) mlcolor(gs8) msymbol(circle)), /*
*/ ytitle("Percent Registered") ttitle("") /*
*/ legend(off) /*
*/ tlabel(`beginyear'q`beginquarter'(8)`endyear'q`temp') /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) 

graph export "Iowa2013QuarterlyReg_nolabel.eps", replace


twoway (scatter perc2012 quarter if quarter <= `cutoff_quarter1', mfcolor(black) mlcolor(black) msymbol(circle)) /*
*/ (scatter perc2012 quarter if quarter > `cutoff_quarter1' & quarter <= `cutoff_quarter2', mfcolor(gs12) mlcolor(gs12) msymbol(circle)) /*
*/ (scatter perc2012 quarter if quarter > `cutoff_quarter2' & quarter <= `cutoff_quarter3', mfcolor(white) mlcolor(black) msymbol(circle)) /*
*/ (scatter perc2012 quarter if quarter > `cutoff_quarter3' & quarter <= `cutoff_quarter4', mfcolor(gs12) mlcolor(black) msymbol(circle)) /*
*/ (scatter perc2012 quarter if quarter > `cutoff_quarter4', mfcolor(gs8) mlcolor(gs8) msymbol(circle)), /*
*/ ytitle("Percent Voting in 2012 Presidential Election") ttitle("") /*
*/ legend(lab(1 "Not Notified that Eligible in 2008") /*
*/ lab(2 "Notified that Eligible in 2008") /*
*/ lab(3 "Notified that Eligible in 2010") /*
*/ lab(4 "Notified that Eligible in 2010") /*
*/ lab(5 "Must Apply to be Eligible in 2012") position(6) rows(3) region(lstyle(none))) /*
*/ tlabel(`beginyear'q`beginquarter'(8)`endyear'q`temp') /*
*/ plotregion(color(white)) graphregion(color(white)) ylabel(,nogrid) 

graph export "Iowa2013Quarterly2012.eps", replace

log close
