// Add the Path to Read in Datasets Here (Output Will Go In Same Folder)
cd "/Users/marcmere/Box Sync/QJPS Paper/Replication Data-1/"
cap log close
log using "Discharges.log", replace

/* 
Results for:
// Table 1 */

// Add .ado that count the # of unique observations in an active dataset
ssc install unique

clear all
set more off

matrix Felon = J(9, 13, -9)

//
// Observable Chacteristics of All Iowa Discharges from post 1/1/2002 - 2/28/2012
// Only Observe Gender and Age
// Row 1 is All Discharges
// Row 2 is Felony Discharges
//

use "VFFelonMatch01082013_0.dta", clear

// Drops All Discharges from Before 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001

// Creates Male Indicator 
gen Male = (sex == "Male")

// Creates Age Bin Indicators
gen age = real(reverse(substr(reverse(dischargedate), 1, 4))) - year

gen Age1824 = 0
replace Age1824 = 1 if age >= 18 & age <= 24

gen Age2529 = 0
replace Age2529 = 1 if age >= 25 & age <= 29

gen Age3039 = 0
replace Age3039 = 1 if age >= 30 & age <= 39

gen Age4049 = 0
replace Age4049 = 1 if age >= 40 & age <= 49

gen Age50U = 0
replace Age50U = 1 if age >= 50
drop age

// Creates Indicator for Whether Discharge was for a Felony
tab offenseclass
gen felony = (regexm(offenseclass, "Felony"))

// Number of Unique People Discharged and Unique People Discharged from Felony
unique ID
unique ID if felony 

local j = 1
qui foreach var of varlist Male-Age50U {
regress `var' [pweight = 1]
// Demographics of All Iowa Discharges
matrix Felon[1, `j'] = _b[_cons]
// Demographics of Felon Iowa Discharges
regress `var' [pweight = 1] if felony
matrix Felon[2, `j'] = _b[_cons]
local j = `j' + 1
}

//
// Observable Chacteristics of All Maine Discharges from post 1/1/2009 - 12/31/2010
// Only Observe Gender, Age, and Race
// Row 3 is All Discharges
//

use "VFFelonMatch_0.dta", clear
// Only Keep Discharges from 2009 and 2010
keep if substr(tdate, 7, 2) == "09" | substr(tdate, 7, 2) == "10" 

// Creates Male Indicator 
gen Male = (gender == "M")

// Creates Age Bin Indicators
gen age = 2000 + real(substr(tdate, 7, 2)) - year

gen Age1824 = 0
replace Age1824 = 1 if age >= 18 & age <= 24

gen Age2529 = 0
replace Age2529 = 1 if age >= 25 & age <= 29

gen Age3039 = 0
replace Age3039 = 1 if age >= 30 & age <= 39

gen Age4049 = 0
replace Age4049 = 1 if age >= 40 & age <= 49

gen Age50U = 0
replace Age50U = 1 if age >= 50
drop age

// Creates Black Indicator 
gen Black = (e_race_desc == "Black or African American")

// Number of Unique People Discharged 
unique ID

local j = 1
qui foreach var of varlist Male-Black {
regress `var' [pweight = 1]
matrix Felon[3, `j'] = _b[_cons]
local j = `j' + 1
}

//
// Observable Chacteristics of All Rhode Island Discharges from post 1/1/2009 - 12/31/2010
// Only Observe Gender, Age, and Race
// Row 4 is All Discharges
// Row 5 is Felony Discharges
//

use "VFFelonMatch12232013_0.dta", clear
// Only Keep Discharges from 2009 and 2010
keep if year(ReleaseDate) >= 2009 & year(ReleaseDate) <= 2010

// Creates Male Indicator 
gen Male = (Sex == "Male")

// Creates Age Bin Indicators
gen age = year(ReleaseDate) - year

gen Age1824 = 0
replace Age1824 = 1 if age >= 18 & age <= 24

gen Age2529 = 0
replace Age2529 = 1 if age >= 25 & age <= 29

gen Age3039 = 0
replace Age3039 = 1 if age >= 30 & age <= 39

gen Age4049 = 0
replace Age4049 = 1 if age >= 40 & age <= 49

gen Age50U = 0
replace Age50U = 1 if age >= 50
drop age

// Creates Black Indicator 
gen Black = (Race == "Black")
// Creates Hispanic Indicator 
gen Hispanic = (Race == "Hispanic")

// Creates Indicator for Whether Discharge was for a Felony
gen felony = (FelonyMisd == "Felony")

// Number of Unique People Discharged and Unique People Discharged from Felony
unique ID
unique ID if felony

local j = 1
qui foreach var of varlist Male-Hispanic {
regress `var' [pweight = 1]
matrix Felon[4, `j'] = _b[_cons]
regress `var' [pweight = 1] if felony
matrix Felon[5, `j'] = _b[_cons]
local j = `j' + 1
}

//
// Observable Chacteristics of NACJD Sample
// Row 6 is Full Sample of Citizens
// Row 7 is Iowa Citizens
// Row 8 is New England Ciziens
// Row 9 is Citizens To Be Released in Month of Interview or Following Month
//

infix str sex 14 str age 32-34 str hispanic 43 str black 74 /*
*/ str usa 82 str citizen1 92 str citizen2 101 str married 102 /*
*/ str education 4479-4480 str education2 4481 str month_rel 5671-5672 /*
*/ str year_rel 5673-5676 str state 2997-2998 str weight 8588-8596 /*
*/ str month_int 8703-8704 str year_int 8699-8702 /*
*/ using "04572-0002-Data.txt", clear

// Restricts Sample to US Citizens
keep if usa == "1" | citizen1 == "1" | citizen2 == "1"
drop usa citizen1 citizen2

// Creates Male Indicator 
gen Male = (sex == "1")

// Creates Age Bin Indicators
destring age, force replace
keep if age >= 18

gen Age1824 = 0
replace Age1824 = 1 if age >= 18 & age <= 24

gen Age2529 = 0
replace Age2529 = 1 if age >= 25 & age <= 29

gen Age3039 = 0
replace Age3039 = 1 if age >= 30 & age <= 39

gen Age4049 = 0
replace Age4049 = 1 if age >= 40 & age <= 49

gen Age50U = 0
replace Age50U = 1 if age >= 50

// Creates Black Indicator 
gen Black = 1 if black == "2"
replace Black = 0 if black == "9"

// Creates Hispanic Indicator 
gen Hispanic = 1 if hispanic == "1"
replace Hispanic = 0 if hispanic == "2"

// Creates Indicator for Being Married
gen Married = (married == "1")

// Creates Education Bin Indicators
destring education education2, force replace
gen NoHS = (education <= 11 | (education == 12 & education2 == 2))
gen HS = (education == 12 & education2 == 1)
gen SomeCol = ((education >= 13 & education <= 15) | /*
*/ (education == 16 & education2 == 2))
gen Col = ((education == 16 & education2 == 1) | /*
*/ (education >= 17 & education <= 18))

// Creates Indictor if Person is to be Discharged in Month of Interview or Following Month
destring year_rel month_rel month_int year_int, force replace
gen recent = 0
replace recent = 1 if (year_rel == year_int) & (month_rel == month_int)
replace recent = 1 if (year_rel == year_int) & (month_rel - 1 == month_int)
replace recent = 1 if (year_rel + 1 == year_int) & month_rel == 1 & month_int == 12

tab state
// Creates Indicator for Being from Iowa
gen Iowa = (state == "19")
// Creates Indicator for Being from New England (Connecticut, Maine, Massachusettes
// New Hampshire, Rhode Island, or Vermont)
gen NewEngland = (state == "09" | state == "23" | state == "25" | /*
*/ state == "33" | state == "44" | state == "50")

destring weight, force replace

// Counts # of Obs. with a Positive Weight for Each Group
count if weight > 0
count if weight > 0 & Iowa
count if weight > 0 & NewEngland
count if weight > 0 & recent

local j = 1
qui foreach var of varlist Male-Col {
regress `var' [pweight = weight]
matrix Felon[6, `j'] = _b[_cons]
regress `var' [pweight = weight] if Iowa
matrix Felon[7, `j'] = _b[_cons]
regress `var' [pweight = weight] if NewEngland
matrix Felon[8, `j'] = _b[_cons]
regress `var' [pweight = weight] if recent
matrix Felon[9, `j'] = _b[_cons]
local j = `j' + 1
}

// Lists Table 1 (N's from Log File Added in Excel)
// Row 1 is All Iowa Discharges
// Row 2 is Felony Iowa Discharges
// Row 3 is All Maine Discharges
// Row 4 is All Rhode Island Discharges
// Row 5 is Felony Rhode Island Discharges
// Row 6 is All NACJD Citizens
// Row 7 is Iowa NACJD Citizens
// Row 8 is New England NACJD Citizens
// Row 9 is NACJD Citizens To Be Released in Month of Interview or Following Month
// -9 Indicates Missing

matlist Felon

log close
