// Add the Path to Read in Datasets Here (Output Will Go In Same Folder)
cd "/Users/marcmere/Box Sync/QJPS Paper/Replication Data-1/"
cap log close
log using "Iowa2008.log", replace

/* 
Results for:
// Table 3 */

clear all
set more off

matrix Table = J(6, 8, -9)

local beginyear = "2002"
local beginmonth = "01"
local endyear = "2008"
local endmonth = "09"
local lowerbound = monthly("`beginyear'-`beginmonth'", "YM")
local upperbound = monthly("`endyear'-`endmonth'", "YM")
local cutoff_month1 = monthly("2005-06", "YM")
local cutoff_date1 = date("2005-06-30", "YMD")

use "VFFelonMatch2010_0.dta", clear

gen monthstring = reverse(substr(reverse(dischargedate), 1, 4)) + "-" + subinstr(substr(dischargedate, 1, 2), "/","",1)
gen month = monthly(monthstring, "YM")
keep if month >= `lowerbound' & month <= `upperbound'

// Creates Indictor for Whether Ever Discharged for Felony
gen Felony = regexm(offenseclass,"Felony")
egen Felon = max(Felony), by(ID)

// Creates Indictor for Whether Someone Was Discharged Between 2002 and 2003 
// and for Whether Someone Was Discharged for a Felony Between 2002 and 2003
gen temp = 0
replace temp = 1 if real(reverse(substr(reverse(dischargedate), 1, 4))) >= 2002 & /*
*/ real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2003
egen subsample1 = max(temp), by(ID)
egen subsample1XFelon = max(temp*regexm(offenseclass,"Felony")), by(ID)
drop temp

// Creates Indictor for Whether Someone Was Discharged Between 2006 and 2007 
// and for Whether Someone Was Discharged for a Felony Between 2006 and 2007
gen temp = 0
replace temp = 1 if real(reverse(substr(reverse(dischargedate), 1, 4))) >= 2006 & /*
*/ real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2007
egen subsample2 = max(temp), by(ID)
egen subsample2XFelon = max(temp*regexm(offenseclass,"Felony")), by(ID)
drop temp

// Only Keeps Last Discharge from Each Individual
duplicates report ID
sort ID dischargedate
drop if ID == ID[_n-1]

gen NotFelon = 1 - Felon
local temp2 = 0

// 1st Row: All Felons
// 2nd Row: All Felons discharged from 2002/2003
// 3rd Row: All Felons discharged from 2006/2007
// 4th Row: All Non-Felons

foreach sample of varlist Felon subsample1XFelon subsample2XFelon NotFelon {

count if `sample' == 1
local temp = 1
local temp2 = `temp2' + 1
qui sum registered if `sample' == 1
matrix Table[`temp2', `temp'] = r(mean) * 100

foreach var of varlist dem rep np oth {
local temp = `temp' + 1
qui sum `var' if `sample' == 1 & registered == 1
matrix Table[`temp2', `temp'] = r(mean) * 100
}

foreach var of varlist y2004 y2006 y2008 {
local temp = `temp' + 1
qui sum `var' if `sample' == 1
matrix Table[`temp2', `temp'] = r(mean) * 100
}
}

// 5th Row: Discharged in 2002/2003, but not from a Felony
// 6th Row: Discharged in 2006/2007, but not from a Felony

forvalues i = 1(1)2 {
count if subsample`i' == 1 & subsample`i'XFelon == 0
local temp = 1
local temp2 = `temp2' + 1
qui sum registered if subsample`i' == 1 & subsample`i'XFelon == 0
matrix Table[`temp2', `temp'] = r(mean) * 100

foreach var of varlist dem rep np oth {
local temp = `temp' + 1
qui sum `var' if subsample`i' == 1 & subsample`i'XFelon == 0 & registered == 1
matrix Table[`temp2', `temp'] = r(mean) * 100
}

foreach var of varlist y2004 y2006 y2008 {
local temp = `temp' + 1
qui sum `var' if subsample`i' == 1 & subsample`i'XFelon == 0 == 1
matrix Table[`temp2', `temp'] = r(mean) * 100
}
}

matlist Table

log close

