// Add the Path to Read in Datasets Here (Output Will Go In Same Folder)
cd "/Users/marcmere/Box Sync/QJPS Paper/Replication Data-1/"
cap log close
log using "Iowa2012.log", replace

/* 
Results for:
// Table 5 */

matrix Table5 = J(12, 12, -9)

// Compares Discharged in 2005 pre- and post- July 4, 2005

local beginyear = "2005"
local beginmonth = "01"
local endyear = "2005"
local endmonth = "12"
local lowerbound = monthly("`beginyear'-`beginmonth'", "YM")
local upperbound = monthly("`endyear'-`endmonth'", "YM")
local cutoff_date1 = date("2005-07-04", "YMD")

use "VFFelonMatch01082013_0.dta", clear

gen monthstring = reverse(substr(reverse(dischargedate), 1, 4)) + "-" + subinstr(substr(dischargedate, 1, 2), "/","",1)
gen month = monthly(monthstring, "YM")
keep if month >= `lowerbound' & month <= `upperbound'

gen temp1 = real(subinstr(substr(dischargedate, 1, 2), "/","",1))
gen temp2 = real(reverse(subinstr(substr(reverse(dischargedate), 6, 2), "/","",1)))
gen temp3 = real(reverse(substr(reverse(dischargedate), 1, 4)))

gen treated = (mdy(temp1, temp2, temp3) > `cutoff_date1')
gen untreated = (mdy(temp1, temp2, temp3) <= `cutoff_date1')

tab offenseclass
gen felon = regexm(offenseclass, "Felony")
gen misdemeanor = regexm(offenseclass, "Misdemeanor")

forvalues i = 1(1)3 {
gen forcing`i' = (mdy(temp1, temp2, temp3) - `cutoff_date1')^`i'
gen forcing`i'Xtreated = forcing`i' * treated
}
drop temp1 temp2 temp3

// Table 5 (top)

gen all = 1
local temp2 = 1
foreach var2 of varlist all felon misdemeanor {
duplicates report ID if `var2' == 1
local temp = 1
foreach var of varlist registered y2008 y2010 y2012 {
// Difference in Means
qui regress `var' treated if `var2' == 1, robust cluster(ID)
matrix Table5[`temp2',`temp'] = _b[treated]
matrix Table5[`temp2'+1,`temp'] = -_se[treated]
// Linear Time Trends
qui regress `var' treated forcing1* if `var2' == 1, robust cluster(ID)
matrix Table5[`temp2',`temp'+1] = _b[treated]
matrix Table5[`temp2'+1,`temp'+1] = -_se[treated]
// Cubic Time Trends
qui regress `var' treated forcing* if `var2' == 1, robust cluster(ID)
matrix Table5[`temp2',`temp'+2] = _b[treated]
matrix Table5[`temp2'+1,`temp'+2] = -_se[treated]
local temp = `temp' + 3
}
local temp2 = `temp2' + 2
}

// Compares Discharged 7/1/2010 - 12/31/2010 to 1/1/2011 to 6/30/2011

local beginyear = "2010"
local beginmonth = "07"
local endyear = "2011"
local endmonth = "06"
local lowerbound = monthly("`beginyear'-`beginmonth'", "YM")
local upperbound = monthly("`endyear'-`endmonth'", "YM")
local cutoff_date1 = date("2010-12-31", "YMD")

use "VFFelonMatch01082013_0.dta", clear

gen monthstring = reverse(substr(reverse(dischargedate), 1, 4)) + "-" + subinstr(substr(dischargedate, 1, 2), "/","",1)
gen month = monthly(monthstring, "YM")
keep if month >= `lowerbound' & month <= `upperbound'

gen temp1 = real(subinstr(substr(dischargedate, 1, 2), "/","",1))
gen temp2 = real(reverse(subinstr(substr(reverse(dischargedate), 6, 2), "/","",1)))
gen temp3 = real(reverse(substr(reverse(dischargedate), 1, 4)))

gen treated = (mdy(temp1, temp2, temp3) > `cutoff_date1')
gen untreated = (mdy(temp1, temp2, temp3) <= `cutoff_date1')

tab offenseclass
gen felon = regexm(offenseclass, "Felony")
gen misdemeanor = regexm(offenseclass, "Misdemeanor")

forvalues i = 1(1)3 {
gen forcing`i' = (mdy(temp1, temp2, temp3) - `cutoff_date1')^`i'
gen forcing`i'Xtreated = forcing`i' * treated
}
drop temp1 temp2 temp3

// Table 5 (bottom)

gen all = 1
foreach var2 of varlist all felon misdemeanor {
duplicates report ID if `var2' == 1
local temp = 1
foreach var of varlist registered y2008 y2010 y2012 {
// Difference in Means
qui regress `var' treated if `var2' == 1, robust cluster(ID)
matrix Table5[`temp2',`temp'] = _b[treated]
matrix Table5[`temp2'+1,`temp'] = -_se[treated]
// Linear Time Trends
qui regress `var' treated forcing1* if `var2' == 1, robust cluster(ID)
matrix Table5[`temp2',`temp'+1] = _b[treated]
matrix Table5[`temp2'+1,`temp'+1] = -_se[treated]
// Cubic Time Trends
qui regress `var' treated forcing* if `var2' == 1, robust cluster(ID)
matrix Table5[`temp2',`temp'+2] = _b[treated]
matrix Table5[`temp2'+1,`temp'+2] = -_se[treated]
local temp = `temp' + 3
}
local temp2 = `temp2' + 2
}

matlist Table5

log close

