cd "/Users/marcmere/Box Sync/QJPS Paper/Replication Data/"
cap log close
log using "IowaBandwidth.log", replace

/* 
Generates:
// Figure A.6 */

local beginyear = "2002"
local beginmonth = "01"
local endyear = "2008"
local endmonth = "09"
local lowerbound = monthly("`beginyear'-`beginmonth'", "YM")
local upperbound = monthly("`endyear'-`endmonth'", "YM")
local cutoff_month = monthly("2005-06", "YM")
local cutoff_date1 = date("2005-07-04", "YMD")

use "VFFelonMatch2010_0.dta", clear

gen monthstring = reverse(substr(reverse(dischargedate), 1, 4)) + "-" + subinstr(substr(dischargedate, 1, 2), "/","",1)
gen month = monthly(monthstring, "YM")
keep if month >= `lowerbound' & month <= `upperbound'

gen temp1 = real(subinstr(substr(dischargedate, 1, 2), "/","",1))
gen temp2 = real(reverse(subinstr(substr(reverse(dischargedate), 6, 2), "/","",1)))
gen temp3 = real(reverse(substr(reverse(dischargedate), 1, 4)))

gen treated = (mdy(temp1, temp2, temp3) > `cutoff_date1')

forvalues i = 1(1)3 {
gen forcing`i' = (mdy(temp1, temp2, temp3) - `cutoff_date1')^`i'
gen forcing`i'Xtreated = forcing`i' * treated
}
drop temp1 temp2 temp3

matrix estimates = J(30, 5, 0)
forvalue i = 1(1)30 {
qui regress y2008 treated forcing1* if `cutoff_month' <= month + `i' - 1 & `cutoff_month' >= month - `i', robust cluster(ID)
matrix estimates[`i', 1] = _b[treated]
matrix estimates[`i', 2] = _se[treated]
qui regress y2008 treated forcing*  if `cutoff_month' <= month + `i' - 1 & `cutoff_month' >= month - `i', robust cluster(ID)
matrix estimates[`i', 3] = _b[treated]
matrix estimates[`i', 4] = _se[treated]
matrix estimates[`i', 5] = `i'
}

svmat estimates
keep estimates*

rename estimates5 bandwidth

rename estimates1 k1
gen k1_lb = k1 - 1.96 * estimates2
gen k1_ub = k1 + 1.96 * estimates2

rename estimates3 k3
gen k3_lb = k3 - 1.96 * estimates4
gen k3_ub = k3 + 1.96 * estimates4

twoway (scatter k1 bandwidth, mcolor(black) mfcolor(white) msymbol(circle) msize(large)) /*
*/ (rspike k1_ub k1_lb bandwidth, lcolor(black)), /*
*/ legend(off) xtitle("") ytitle("Est. Change in 2008 Turnout from Notification" "k = 1") /*
*/ xlabel(0(3)30) plotregion(color(white)) graphregion(color(white)) ylabel(,grid) 

graph export "IowaBandwidith_k1.eps", replace

twoway (scatter k3 bandwidth, mcolor(black) mfcolor(white) msymbol(circle) msize(large)) /*
*/ (rspike k3_ub k3_lb bandwidth, lcolor(black)), /*
*/ legend(off) xtitle("Bandwidth(# of months)") ytitle("Est. Change in 2008 Turnout from Notification" "k = 3") /*
*/ xlabel(0(3)30) plotregion(color(white)) graphregion(color(white)) ylabel(,grid) 

graph export "IowaBandwidith_k3.eps", replace

log close
