// Add the Path to Read in Datasets Here (Output Will Go In Same Folder)
cd "/Users/marcmere/Box Sync/QJPS Paper/Replication Data-1/"
cap log close
log using "IowaMatching.log", replace

/* 
Results for:
// Table A1
// Table A2
// Table A3 */

clear all
set more off

// Observation Counts

use "VFFelonMatch01082013_0.dta", clear
// All Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001

// Only Keep Individuals' Last Discharge
duplicates report ID
sort ID dischargedate
drop if ID == ID[_n-1]

display _N
count if sex == "Female"
count if sex ~= "Female"

// Table A1
matrix TableA1 = J(9, 2, -9)
local temp = 0

// Baseline Matching Procedure (Birth Date)

foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
use "VFFelonMatch01082013_`num'.dta", clear
// All Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

qui sum registered
matrix TableA1[`temp', 1] = r(N) * r(mean)

qui sum y2012
matrix TableA1[`temp', 2] = r(N) * r(mean)
}

// Exact Matching Procedure (Birth Date)

foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
use "VFFelonMatch01082013_Exact_`num'.dta", clear
// All Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

qui sum registered
matrix TableA1[`temp', 1] = r(N) * r(mean)

qui sum y2012
matrix TableA1[`temp', 2] = r(N) * r(mean)
}

// Exact Matching Procedure (Birth Year)

foreach num of numlist 0 2 -2 {

local temp = `temp' + 1
use "VFFelonMatch01082013_YearOnly_`num'.dta", clear
// All Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

qui sum registered
matrix TableA1[`temp', 1] = r(N) * r(mean)

qui sum y2012
matrix TableA1[`temp', 2] = r(N) * r(mean)
}

// Table A2
matrix TableA2 = J(9, 2, -9)
local temp = 0

foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
// Tens Digit Matches, Ones Digit Doesn't in Year
use "VFFelonMatch01082013_NoYear1_`num'.dta", clear
// All Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

sum registered
matrix TableA2[`temp', 1] = r(N) * r(mean)

sum y2012
matrix TableA2[`temp', 2] = r(N) * r(mean)
}

local temp = 0
foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
// Tens Digit Doesn't Match, Ones Digit Does in Year
use "VFFelonMatch01082013_NoYear2_`num'.dta", clear
// All Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

sum registered
local crap1 = r(N) * r(mean)
local crap2 = TableA2[`temp', 1]
matrix TableA2[`temp', 1] = `crap1' + `crap2'

sum y2012
local crap1 = r(N) * r(mean)
local crap2 = TableA2[`temp', 2]
matrix TableA2[`temp', 2] = `crap1' + `crap2'
}

foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
// Month Doesn't Match
use "VFFelonMatch01082013_NoMonth_`num'.dta", clear
// All Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

qui sum registered
matrix TableA2[`temp', 1] = r(N) * r(mean)

qui sum y2012
matrix TableA2[`temp', 2] = r(N) * r(mean)
}

foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
// Day Doesn't Match
use "VFFelonMatch01082013_NoDay_`num'.dta", clear
// All Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

qui sum registered
matrix TableA2[`temp', 1] = r(N) * r(mean)

qui sum y2012
matrix TableA2[`temp', 2] = r(N) * r(mean)
}

// Table A3
matrix TableA3 = J(18, 2, -9)
local temp = 0

// Females

foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
// Last Name Doesn't Match
use "VFFelonMatch01082013_NoLast_`num'.dta", clear
// All Female Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001
keep if sex == "Female"

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

qui sum registered
matrix TableA3[`temp', 1] = r(N) * r(mean)

qui sum y2012
matrix TableA3[`temp', 2] = r(N) * r(mean)
}

foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
// First Name Doesn't Match
use "VFFelonMatch01082013_NoFirst_`num'.dta", clear
// All Female Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001
keep if sex == "Female"

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

qui sum registered
matrix TableA3[`temp', 1] = r(N) * r(mean)

qui sum y2012
matrix TableA3[`temp', 2] = r(N) * r(mean)
}

foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
// Middle Name Doesn't Match
use "VFFelonMatch01082013_NoMiddle_`num'.dta", clear
// All Female Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001
keep if sex == "Female"

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

qui sum registered
matrix TableA3[`temp', 1] = r(N) * r(mean)

qui sum y2012
matrix TableA3[`temp', 2] = r(N) * r(mean)
}

// Males

foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
// Last Name Doesn't Match
use "VFFelonMatch01082013_NoLast_`num'.dta", clear
// All Female Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001
keep if sex != "Female"

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

qui sum registered
matrix TableA3[`temp', 1] = r(N) * r(mean)

qui sum y2012
matrix TableA3[`temp', 2] = r(N) * r(mean)
}

foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
// First Name Doesn't Match
use "VFFelonMatch01082013_NoFirst_`num'.dta", clear
// All Female Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001
keep if sex != "Female"

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

qui sum registered
matrix TableA3[`temp', 1] = r(N) * r(mean)

qui sum y2012
matrix TableA3[`temp', 2] = r(N) * r(mean)
}

foreach num of numlist 0 35 -35 {

local temp = `temp' + 1
// Middle Name Doesn't Match
use "VFFelonMatch01082013_NoMiddle_`num'.dta", clear
// All Female Observations Since 2002
drop if real(reverse(substr(reverse(dischargedate), 1, 4))) <= 2001
keep if sex != "Female"

// Only Keep Individuals' Last Discharge
sort ID dischargedate
drop if ID == ID[_n-1]

qui sum registered
matrix TableA3[`temp', 1] = r(N) * r(mean)

qui sum y2012
matrix TableA3[`temp', 2] = r(N) * r(mean)
}

matlist TableA1
matlist TableA2
matlist TableA3

log close

