// Add the Path to Read in Datasets Here (Output Will Go In Same Folder)
cd "/Users/marcmere/Box Sync/QJPS Paper/Replication Data-1/"
cap log close
log using "IowaNotification.log", replace

/* 
Results for:
// Table 4
// Table A.5
// Table A.6 */

// Differences in Treated/Untreated in 2005 Discharge Sample
local beginyear = "2005"
local beginmonth = "01"
local endyear = "2005"
local endmonth = "12"
local lowerbound = monthly("`beginyear'-`beginmonth'", "YM")
local upperbound = monthly("`endyear'-`endmonth'", "YM")
local cutoff_date1 = date("2005-07-04", "YMD")

use "VFFelonMatch2010_0.dta", clear

gen monthstring = reverse(substr(reverse(dischargedate), 1, 4)) + "-" + subinstr(substr(dischargedate, 1, 2), "/","",1)
gen month = monthly(monthstring, "YM")
keep if month >= `lowerbound' & month <= `upperbound'

gen temp1 = real(subinstr(substr(dischargedate, 1, 2), "/","",1))
gen temp2 = real(reverse(subinstr(substr(reverse(dischargedate), 6, 2), "/","",1)))
gen temp3 = real(reverse(substr(reverse(dischargedate), 1, 4)))

gen treated = (mdy(temp1, temp2, temp3) > `cutoff_date1')
gen untreated = (mdy(temp1, temp2, temp3) <= `cutoff_date1')

forvalues i = 1(1)3 {
gen forcing`i' = (mdy(temp1, temp2, temp3) - `cutoff_date1')^`i'
gen forcing`i'Xtreated = forcing`i' * treated
}
drop temp1 temp2 temp3

tab sex
gen male = (sex ~= "Female")

tab offenseclass
gen felon = regexm(offenseclass, "Felony")
gen felonyC = (offenseclass == "C Felony")
gen felonyD = (offenseclass == "D Felony")
gen otherfelony = felon - felonyC - felonyD
gen misdemeanor = regexm(offenseclass, "Misdemeanor")

tab dischargereason
gen early = (dischargereason == "Discharge-Early Discharge")

tab offensetype
gen alcohol = (offensesubtype == "Alcohol" | offensesubtype == "OWI")
gen drug = (offensetype == "Drug")
gen property = (offensetype == "Property")
gen violent = (offensetype == "Violent")
gen other = 1 - alcohol - drug - property - violent - other

tab supervisionstatus
gen prison = (supervisionstatus == "Prison")
gen parole = (supervisionstatus == "Parole")
gen probation = 1 - prison - parole 

// Table A.5

matrix TableA5 = J(36, 5, -9)

local temp2 = 0
// Gets Means and Standard Errors of Pre-Treatment Covariates
foreach var2 of varlist treated untreated {
count if `var2' == 1
local temp = 1
local temp2 = `temp2' + 1
foreach var of varlist y2000 y2002 y2004 year male felonyC felonyD otherfelony /*
*/ misdemeanor early alcohol drug property violent other prison parole probation {
qui regress `var' if `var2' == 1, robust cluster(ID)
matrix TableA5[`temp',`temp2'] = _b[_cons]
matrix TableA5[`temp'+1,`temp2'] = -_se[_cons]
local temp = `temp' + 2
}
}

local temp = 1
local temp2 = `temp2' + 1
// Difference in Means in Pre-Treatment Covariates
foreach var of varlist y2000 y2002 y2004 year male felonyC felonyD otherfelony /*
*/ misdemeanor early alcohol drug property violent other prison parole probation {
qui regress `var' treated, robust cluster(ID)
matrix TableA5[`temp',`temp2'] = _b[treated]
matrix TableA5[`temp'+1,`temp2'] = -_se[treated]
local temp = `temp' + 2
}

local temp = 1
local temp2 = `temp2' + 1
// Difference in Pre-Treatment Covariates Controlling for Linear Trends
foreach var of varlist y2000 y2002 y2004 year male felonyC felonyD otherfelony /*
*/ misdemeanor early alcohol drug property violent other prison parole probation {
qui regress `var' treated forcing1*, robust cluster(ID)
matrix TableA5[`temp',`temp2'] = _b[treated]
matrix TableA5[`temp'+1,`temp2'] = -_se[treated]
local temp = `temp' + 2
}

local temp = 1
local temp2 = `temp2' + 1
// Difference in Pre-Treatment Covariates Controlling for Cubic Trends
foreach var of varlist y2000 y2002 y2004 year male felonyC felonyD otherfelony /*
*/ misdemeanor early alcohol drug property violent other prison parole probation {
qui regress `var' treated forcing*, robust cluster(ID)
matrix TableA5[`temp',`temp2'] = _b[treated]
matrix TableA5[`temp'+1,`temp2'] = -_se[treated]
local temp = `temp' + 2
}

// Table 4

matrix Table4 = J(8, 12, -9)
 
gen all = 1
local temp2 = 0
foreach var2 of varlist all felon misdemeanor {
local temp2 = `temp2' + 2
duplicates report ID if `var2' == 1
local temp = 1
foreach var of varlist registered y2004 y2006 y2008 {
// Difference in Means
qui regress `var' treated if `var2' == 1, robust cluster(ID)
matrix Table4[`temp2' - 1, `temp'] = _b[treated]
matrix Table4[`temp2', `temp'] = -_se[treated]
// Linear Time Trends
qui regress `var' treated forcing1* if `var2' == 1, robust cluster(ID)
matrix Table4[`temp2' - 1, `temp' + 1] = _b[treated]
matrix Table4[`temp2', `temp' + 1] = -_se[treated]
// Cubic Time Trends
qui regress `var' treated forcing* if `var2' == 1, robust cluster(ID)
matrix Table4[`temp2' - 1, `temp' + 2] = _b[treated]
matrix Table4[`temp2', `temp' + 2] = -_se[treated]
local temp = `temp' + 3
}
}

forvalues i = 1(1)12 {
matrix Table4[7, `i'] = Table4[3, `i'] - Table4[5, `i']
local sediff = (Table4[4, `i']^2 + Table4[6, `i']^2)^(1/2)
matrix Table4[8, `i'] = 2*(1 - normal(abs(Table4[7, `i'])/`sediff'))
}

// Table A.6

matrix TableA6 = J(16, 6, -9)

gen temp1 = real(substr(eff_regn_date1, 1, 2))
gen temp2 = real(substr(eff_regn_date1, 4, 2))
gen temp3 = real(substr(eff_regn_date1, 7, 4))
gen dor = mdy(temp1, temp2, temp3)

local temp2 = 1
foreach var of varlist all felon {
count if `var' == 1 & treated
count if `var' == 1 & untreated
local temp = 1
foreach num of numlist 2000 2004 2005 2006 2007 2008 2009 2010 {
qui gen temp = 0
qui replace temp = 1 if dor <= mdy(12, 31, `num') & missing(dor) == 0
qui regress temp treated if `var' == 1
// Percent of Treated Registrered by the End of Year `num'
matrix TableA6[`temp',`temp2'] = _b[_cons] + _b[treated]
qui mat V = e(V)
matrix TableA6[`temp'+1,`temp2'] = -(V[1,1] + 2*V[1,2] + V[2,2])^(1/2)
// Percent of Untreated Registrered by the End of Year `num'
matrix TableA6[`temp',`temp2'+1] = _b[_cons] 
matrix TableA6[`temp'+1,`temp2'+1] =  -_se[_cons]
// Difference in Registion by the End of Year `num'
matrix TableA6[`temp',`temp2'+2] = _b[treated]
matrix TableA6[`temp'+1,`temp2'+2] = -_se[treated]
qui drop temp
local temp = `temp' + 2
}
local temp2 = `temp2' + 3
}

matlist TableA5
matlist Table4
matlist TableA6

// Descriptive Statistics (Not in Tables, but cited in Text)

sum registered y2008 y2006 y2004 if treated & all
sum registered y2008 y2006 y2004 if untreated & all

sum registered y2008 y2006 y2004 if treated & felon
sum registered y2008 y2006 y2004 if untreated & felon

sum registered y2008 y2006 y2004 if treated & misdemeanor
sum registered y2008 y2006 y2004 if untreated & misdemeanor

log close

