cd "/Users/marcmere/Box Sync/QJPS Paper/Replication Data/"
cap log close
log using "IowaPlacebo.log", replace

/* 
Generates:
// Figure A.5 */

clear all
set more off
graph set ps logo off
graph set ps pagesize a4

matrix estimates = J(6, 4, 0)

forvalues i = 2002(1)2007 {

local beginyear = "`i'"
local beginmonth = "01"
local endyear = "`i'"
local endmonth = "12"
local lowerbound = monthly("`beginyear'-`beginmonth'", "YM")
local upperbound = monthly("`endyear'-`endmonth'", "YM")
local cutoff_month = monthly("`i'-06", "YM")
local cutoff_date1 = date("`i'-07-04", "YMD")

use "VFFelonMatch2010_0.dta", clear

gen monthstring = reverse(substr(reverse(dischargedate), 1, 4)) + "-" + subinstr(substr(dischargedate, 1, 2), "/","",1)
gen month = monthly(monthstring, "YM")
keep if month >= `lowerbound' & month <= `upperbound'

gen temp1 = real(subinstr(substr(dischargedate, 1, 2), "/","",1))
gen temp2 = real(reverse(subinstr(substr(reverse(dischargedate), 6, 2), "/","",1)))
gen temp3 = real(reverse(substr(reverse(dischargedate), 1, 4)))

gen treated = (mdy(temp1, temp2, temp3) > `cutoff_date1')

forvalues j = 1(1)3 {
gen forcing`j' = (mdy(temp1, temp2, temp3) - `cutoff_date1')^`j'
gen forcing`j'Xtreated = forcing`j' * treated
}
drop temp1 temp2 temp3

qui regress y2008 treated forcing1*, robust cluster(ID)
matrix estimates[`i' - 2001, 1] = _b[treated]
matrix estimates[`i' - 2001, 2] = _se[treated]
qui regress y2008 treated forcing*, robust cluster(ID)
matrix estimates[`i' - 2001, 3] = _b[treated]
matrix estimates[`i' - 2001, 4] = _se[treated]
}

svmat estimates
keep estimates*
keep if missing(estimates1) == 0

rename estimates1 k1
gen k1_lb = k1 - 1.96 * estimates2
gen k1_ub = k1 + 1.96 * estimates2

rename estimates3 k3
gen k3_lb = k3 - 1.96 * estimates4
gen k3_ub = k3 + 1.96 * estimates4

gen year_plus = _n + 2001 + .15
gen year_minus = _n + 2001 - .15

twoway (scatter k3 year_plus, mcolor(black) mfcolor(white) msymbol(circle) msize(large)) /*
*/ (rspike k3_ub k3_lb year_plus, lcolor(black)) /*
*/ (scatter k1 year_minus, mcolor(black) mfcolor(black) msymbol(circle) msize(large)) /*
*/ (rspike k1_ub k1_lb year_minus, lcolor(black)), /*
*/ legend(off) xtitle("Year") ytitle("Est. Change in 2008 Turnout from Post-7/4 Discharge" "Black Circle (k = 1), White Circle (k = 3)") /*
*/ xlabel(2002(1)2007) plotregion(color(white)) graphregion(color(white)) ylabel(,grid) 

graph export "IowaPlacebo.eps", replace

log close
