// Add the Path to Read in Datasets Here (Output Will Go In Same Folder)
cd "/Users/marcmere/Box Sync/QJPS Paper/Replication Data-1/"
cap log close
log using "UggenManza.log", replace

/* 
Results for:
// Table A.8 */

clear all 
set more off

matrix TableA8 = J(26, 6, -9)

infix str PES1 951-952 str PWSSWGT 613-622 str PTDTRACE 139-140 /*
*/ str PRDTHSP 141-142 str PEEDUCA 137-138 str PESEX 129-130 /*
*/ str PEMARITL 125-126 str PEAGE 122-123 str PEMLR 180-181 /*
*/ str GESTCEN 91-92 using "nov12pub.dat", clear
 
destring PES1 PWSSWGT PTDTRACE PRDTHSP PEEDUCA PESEX PEMARITL PEAGE PEMLR /*
*/ GESTCEN, force replace
 
tab PES1
// did not vote, did not know, refused, or provided no response = 0
gen Vote = .
replace Vote = 1 if PES1 == 1
replace Vote = 0 if PES1 == 2
replace Vote = 0 if PES1 == -2
replace Vote = 0 if PES1 == -3
replace Vote = 0 if PES1 == -9
tab Vote
replace PWSSWGT = PWSSWGT / 10000
tab Vote [iweight = PWSSWGT]

// Black Indicator
gen Black = 0
replace Black = 1 if PTDTRACE == 2
replace Black = 1 if PTDTRACE == 6
replace Black = 1 if PTDTRACE == 10
replace Black = 1 if PTDTRACE == 11
replace Black = 1 if PTDTRACE == 12
replace Black = 1 if PTDTRACE == 15
replace Black = 1 if PTDTRACE == 16
replace Black = 1 if PTDTRACE == 19

// Hispanic Indicator
gen Hispanic = 0
replace Hispanic = 1 if PRDTHSP >= 1 & PRDTHSP <= 5

// Education Indicators (Gradudate College Excluded)

gen NoHS = 0 if PEEDUCA ~= -1
replace NoHS = 1 if PEEDUCA == 31
replace NoHS = 1 if PEEDUCA == 32
replace NoHS = 1 if PEEDUCA == 33
replace NoHS = 1 if PEEDUCA == 34
replace NoHS = 1 if PEEDUCA == 35
replace NoHS = 1 if PEEDUCA == 36
replace NoHS = 1 if PEEDUCA == 37
replace NoHS = 1 if PEEDUCA == 38

gen HS = 0 if PEEDUCA ~= -1
replace HS = 1 if PEEDUCA == 39

gen SomeCol = 0 if PEEDUCA ~= -1
replace SomeCol = 1 if PEEDUCA == 40
replace SomeCol = 1 if PEEDUCA == 41
replace SomeCol = 1 if PEEDUCA == 42

// Male Indicator
gen Male = 0 if PESEX == 2
replace Male = 1 if PESEX == 1

// Married Indicator
gen Married = 0 if PEMARITL ~= -1
replace Married = 1 if PEMARITL == 1
replace Married = 1 if PEMARITL == 2

// Age Groups (Over 85 Excluded Group)

gen Age1819 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age1819 = 1 if PEAGE >= 18 & PEAGE <= 19

gen Age2024 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age2024 = 1 if PEAGE >= 20 & PEAGE <= 24

gen Age2529 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age2529 = 1 if PEAGE >= 25 & PEAGE <= 29

gen Age3034 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age3034 = 1 if PEAGE >= 30 & PEAGE <= 34

gen Age3539 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age3539 = 1 if PEAGE >= 35 & PEAGE <= 39

gen Age4044 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age4044 = 1 if PEAGE >= 40 & PEAGE <= 44

gen Age4549 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age4549 = 1 if PEAGE >= 45 & PEAGE <= 49

gen Age5054 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age5054 = 1 if PEAGE >= 50 & PEAGE <= 54

gen Age5559 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age5559 = 1 if PEAGE >= 55 & PEAGE <= 59

gen Age6064 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age6064 = 1 if PEAGE >= 60 & PEAGE <= 64

gen Age6569 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age6569 = 1 if PEAGE >= 65 & PEAGE <= 69

gen Age7074 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age7074 = 1 if PEAGE >= 70 & PEAGE <= 74

gen Age7579 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age7579 = 1 if PEAGE >= 75 & PEAGE <= 79

gen Age8084 = 0 if PEAGE >= 18 & PEAGE <= 85
replace Age8084 = 1 if PEAGE >= 80 & PEAGE <= 84

// Employed Indicator
gen Employed = 0 if PEMLR >= 1 & PEMLR <= 7
replace Employed = 1 if PEMLR >= 1 & PEMLR <= 2 

// Iowa Resident Indicator
gen Iowa = 0
replace Iowa = 1 if GESTCEN == 42

// Maine Resident Indicator
gen Maine = 0
replace Maine = 1 if GESTCEN == 11

// Rhode Island Resident Indicator
gen RI = 0
replace RI = 1 if GESTCEN == 15

// Regression w/o Employment Status (Coeff. in Col. 1, Std. Errors in Col. 2)
local i = 1
local j = 1
logit Vote Black Hispanic NoHS HS SomeCol Male Married Age* [pweight = PWSSWGT]
foreach var of varlist Black Hispanic NoHS HS SomeCol Male Married Age* {
local `var'`i' = _b[`var']
matrix TableA8[`j', 1] =_b[`var']
matrix TableA8[`j', 2] =-_se[`var']
local j = `j' + 1
}
local j = `j' + 4
local cons`i' = _b[_cons]
matrix TableA8[`j', 1] =_b[_cons]
matrix TableA8[`j', 2] =-_se[_cons]

// Regression w Employment Status (Coeff. in Col. 3, Std. Errors in Col. 4)
local i = 2
local j = 1
logit Vote Black Hispanic NoHS HS SomeCol Male Married Age* Employed [pweight = PWSSWGT]
foreach var of varlist Black Hispanic NoHS HS SomeCol Male Married Age* {
local `var'`i' = _b[`var']
matrix TableA8[`j', 3] =_b[`var']
matrix TableA8[`j', 4] =-_se[`var']
local j = `j' + 1
}
local Employed2 = _b[Employed]
matrix TableA8[`j', 3] =_b[Employed]
matrix TableA8[`j', 4] =-_se[Employed]
local j = `j' + 4
local cons`i' = _b[_cons]
matrix TableA8[`j', 3] =_b[_cons]
matrix TableA8[`j', 4] =_se[_cons]

// Regression w Employment Status (Coeff. in Col. 5, Std. Errors in Col. 6)
local i = 3
local j = 1
logit Vote Black Hispanic NoHS HS SomeCol Male Married Age* Iowa Maine RI [pweight = PWSSWGT]
foreach var of varlist Black Hispanic NoHS HS SomeCol Male Married Age* {
local `var'`i' = _b[`var']
matrix TableA8[`j', 5] =_b[`var']
matrix TableA8[`j', 6] =-_se[`var']
local j = `j' + 1
}
local j = `j' + 1
local Iowa3 = _b[Iowa]
matrix TableA8[`j', 5] =_b[Iowa]
matrix TableA8[`j', 6] =-_se[Iowa]
local j = `j' + 1
local Maine3 = _b[Maine]
matrix TableA8[`j', 5] =_b[Maine]
matrix TableA8[`j', 6] =-_se[Maine]
local j = `j' + 1
local RI3 = _b[RI]
matrix TableA8[`j', 5] =_b[RI]
matrix TableA8[`j', 6] =-_se[RI]
local j = `j' + 1
local cons`i' = _b[_cons]
matrix TableA8[`j', 5] =_b[_cons]
matrix TableA8[`j', 6] =_se[_cons]

matlist TableA8

//
// Constructs the Predicted Probability of Voting for NAJCD Sample in CPS Data
//

infix str sex 14 str age 32-34 str hispanic 43 str black 74 /*
*/ str usa 82 str citizen1 92 str citizen2 101 str married 102 /*
*/ str education 4479-4480 str education2 4481 str month_rel 5671-5672 /*
*/ str year_rel 5673-5676 str state 2997-2998 str weight 8588-8596 /*
*/ str month_int 8703-8704 str year_int 8699-8702 /*
*/ using "04572-0002-Data.txt", clear

keep if usa == "1" | citizen1 == "1" | citizen2 == "1"
drop usa citizen1 citizen2

gen Male = (sex == "1")

destring age, force replace
keep if age >= 18

gen Age1819 = 0
replace Age1819 = 1 if age >= 18 & age <= 19

gen Age2024 = 0
replace Age2024 = 1 if age >= 20 & age <= 24

gen Age2529 = 0
replace Age2529 = 1 if age >= 25 & age <= 29

gen Age3034 = 0
replace Age3034 = 1 if age >= 30 & age <= 34

gen Age3539 = 0
replace Age3539 = 1 if age >= 35 & age <= 39

gen Age4044 = 0
replace Age4044 = 1 if age >= 40 & age <= 44

gen Age4549 = 0
replace Age4549 = 1 if age >= 45 & age <= 49

gen Age5054 = 0
replace Age5054 = 1 if age >= 50 & age <= 54

gen Age5559 = 0
replace Age5559 = 1 if age >= 55 & age <= 59

gen Age6064 = 0
replace Age6064 = 1 if age >= 60 & age <= 64

gen Age6569 = 0
replace Age6569 = 1 if age >= 65 & age <= 69

gen Age7074 = 0
replace Age7074 = 1 if age >= 70 & age <= 74

gen Age7579 = 0
replace Age7579 = 1 if age >= 75 & age <= 79

gen Age8084 = 0 
replace Age8084 = 1 if age >= 80 & age <= 84

gen Black = 1 if black == "2"
replace Black = 0 if black == "9"

gen Hispanic = 1 if hispanic == "1"
replace Hispanic = 0 if hispanic == "2"

gen Married = (married == "1")

destring education education2, force replace
gen NoHS = (education <= 11 | (education == 12 & education2 == 2))
gen HS = (education == 12 & education2 == 1)
gen SomeCol = ((education >= 13 & education <= 15) | /*
*/ (education == 16 & education2 == 2))
gen Col = ((education == 16 & education2 == 1) | /*
*/ (education >= 17 & education <= 18))

destring year_rel month_rel month_int year_int, force replace
gen recent = 0
replace recent = 1 if (year_rel == year_int) & (month_rel == month_int)
replace recent = 1 if (year_rel == year_int) & (month_rel - 1 == month_int)
replace recent = 1 if (year_rel + 1 == year_int) & month_rel == 1 & month_int == 12

tab state
gen Iowa = (state == "19")
gen NewEngland = (state == "09" | state == "23" | state == "25" | /*
*/ state == "33" | state == "44" | state == "50")

destring weight, force replace

// Prob1 is the Predicted Probability Ignoring Employment Status
// Prob1 is the Predicted Probability Assuming Unemployed
gen logit1 = `cons1'
gen logit2 = `cons2'
foreach var of varlist Black-SomeCol Male Married Age* {
replace logit1 = logit1 + ``var'1' * `var'
replace logit2 = logit2 + ``var'2' * `var'
}
gen Prob1 = exp(logit1) / (exp(logit1) + 1)
gen Prob2 = exp(logit2) / (exp(logit2) + 1)

foreach var of varlist Prob1 Prob2 {
// Average Turnout Probability for Full Sample
regress `var' [pweight = weight]
// Average Turnout Probability for Iowa Residents
regress `var' [pweight = weight] if Iowa
// Average Turnout Probability for New England Residents
regress `var' [pweight = weight] if NewEngland 
// Average Turnout Probability for People About to Be Discharged
regress `var' [pweight = weight] if recent  
}

matlist TableA8

log close
